ClickyStyle class

Constructors

ClickyStyle({Color color = const Color.fromARGB(18, 0, 0, 0), double borderRadius = 10, ShrinkScale shrinkScale = const ShrinkScale.byRatio(0.05), Curve curveColorIn = Curves.easeOut, Curve curveColorOut = Curves.easeOut, Curve curveSizeIn = Curves.easeOut, Curve curveSizeOut = Curves.easeOut, Duration durationIn = const Duration(milliseconds: 120), Duration durationOut = const Duration(milliseconds: 120), double boundaryFromInitialTouchPoint = 70, double boundaryFromWidgetOutline = 0, ClickyBoundaryStyle boundaryStyle = ClickyBoundaryStyle.fromInitialTouchPoint})
const

Properties

borderRadius double
final
boundaryFromInitialTouchPoint double
final
boundaryFromWidgetOutline double
final
boundaryStyle ClickyBoundaryStyle
final
color Color
the color of the clicky effect
final
curveColorIn Curve
final
curveColorOut Curve
final
curveSizeIn Curve
final
curveSizeOut Curve
final
durationIn Duration
final
durationOut Duration
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shrinkScale ShrinkScale
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited